@@ -11,13 +11,13 @@ These include:
 """
 import contextlib
 from itertools import product
-import warnings
 
 import numpy as np
 from scipy.ndimage import gaussian_filter, zoom as scipy_zoom
 import xarray as xr
 
 from .. import constants as mpconsts
+from .._warnings import warn
 from ..package_tools import Exporter
 from ..units import check_units, masked_array, units
 from ..xarray import preprocess_and_wrap
@@ -93,7 +93,7 @@ def wind_direction(u, v, convention='from'):
     origshape = wdir.shape
     wdir = np.atleast_1d(wdir)
 
-    # Handle oceanographic convection
+    # Handle oceanographic convention
     if convention == 'to':
         wdir -= units.Quantity(180., 'deg')
     elif convention not in ('to', 'from'):
@@ -246,6 +246,18 @@ def heat_index(temperature, relative_humidity, mask_undefined=True):
         A flag indicating whether a masked array should be returned with
         values masked where the temperature < 80F. Defaults to `True`.
 
+    Examples
+    --------
+    >>> from metpy.calc import heat_index
+    >>> from metpy.units import units
+    >>> heat_index(30 * units.degC, 90 * units.percent)
+    <Quantity([40.774647], 'degree_Celsius')>
+    >>> heat_index(90 * units.degF, 90 * units.percent)
+    <Quantity([121.901204], 'degree_Fahrenheit')>
+    >>> heat_index(60 * units.degF, 90 * units.percent)
+    <Quantity([--], 'degree_Fahrenheit')>
+    >>> heat_index(60 * units.degF, 90 * units.percent, mask_undefined=False)
+    <Quantity([59.93], 'degree_Fahrenheit')>
 
     .. versionchanged:: 1.0
        Renamed ``rh`` parameter to ``relative_humidity``
@@ -326,7 +338,7 @@ def heat_index(temperature, relative_humidity, mask_undefined=True):
         if mask.any():
             hi = masked_array(hi, mask=mask)
 
-    return hi
+    return hi.to(temperature.units)
 
 
 @exporter.export
@@ -393,8 +405,8 @@ def apparent_temperature(temperature, relative_humidity, speed, face_level_winds
     # NB: older numpy.ma.where does not return a masked array
     app_temperature = masked_array(
         np.ma.where(masked_array(wind_chill_temperature).mask,
-                    heat_index_temperature.to(temperature.units),
-                    wind_chill_temperature.to(temperature.units)
+                    heat_index_temperature.m_as(temperature.units),
+                    wind_chill_temperature.m_as(temperature.units)
                     ), temperature.units)
 
     # If mask_undefined is False, then set any masked values to the temperature
@@ -527,16 +539,10 @@ def geopotential_to_height(geopotential):
     --------
     >>> import metpy.calc
     >>> from metpy.units import units
-    >>> height = np.linspace(0, 10000, num=11) * units.m
-    >>> geopot = metpy.calc.height_to_geopotential(height)
-    >>> geopot
-    <Quantity([     0.           9805.11097983 19607.1448853  29406.10316465
-    39201.98726524 48994.79863351 58784.53871501 68571.20895435
-    78354.81079527 88135.34568058 97912.81505219], 'meter ** 2 / second ** 2')>
+    >>> geopot = units.Quantity([0., 9805., 19607., 29406.], 'm^2/s^2')
     >>> height = metpy.calc.geopotential_to_height(geopot)
     >>> height
-    <Quantity([     0.   1000.   2000.   3000.   4000.   5000.   6000.   7000.   8000.
-    9000.  10000.], 'meter')>
+    <Quantity([   0.          999.98867965 1999.98521653 2999.98947022], 'meter')>
 
     See Also
     --------
@@ -823,6 +829,9 @@ def smooth_gaussian(scalar_grid, n):
     num_ax = len(scalar_grid.shape)
     # Assume the last two axes represent the horizontal directions
     sgma_seq = [sgma if i > num_ax - 3 else 0 for i in range(num_ax)]
+    # Drop units as necessary to avoid warnings from scipy doing so--units will be reattached
+    # if necessary by wrapper
+    scalar_grid = getattr(scalar_grid, 'magnitude', scalar_grid)
 
     filter_args = {'sigma': sgma_seq, 'truncate': 2 * np.sqrt(2)}
     if hasattr(scalar_grid, 'mask'):
@@ -1098,6 +1107,8 @@ def zoom_xarray(input_field, zoom, output=None, order=3, mode='constant', cval=0
         available.
 
     """
+    # Dequantify input to avoid warnings and make sure units propagate
+    input_field = input_field.metpy.dequantify()
     # Zoom data
     zoomed_data = scipy_zoom(
         input_field.data, zoom, output=output, order=order, mode=mode, cval=cval,
@@ -1294,6 +1305,5 @@ def _check_radians(value, max_radians=2 * np.pi):
     with contextlib.suppress(AttributeError):
         value = value.to('radians').m
     if np.any(np.greater(np.abs(value), max_radians)):
-        warnings.warn('Input over {} radians. '
-                      'Ensure proper units are given.'.format(np.nanmax(max_radians)))
+        warn(f'Input over {np.nanmax(max_radians)} radians. Ensure proper units are given.')
     return value
