@@ -8,14 +8,15 @@ import pytest
 import xarray as xr
 
 from metpy.interpolate import cross_section, geodesic, interpolate_to_slice
-from metpy.testing import assert_array_almost_equal
+from metpy.testing import assert_array_almost_equal, needs_cartopy
+from metpy.units import units
 
 
 @pytest.fixture()
 def test_ds_lonlat():
     """Return dataset on a lon/lat grid with no time coordinate for use in tests."""
-    data_temp = np.linspace(250, 300, 5 * 6 * 7).reshape((5, 6, 7))
-    data_rh = np.linspace(0, 1, 5 * 6 * 7).reshape((5, 6, 7))
+    data_temp = np.linspace(250, 300, 5 * 6 * 7).reshape((5, 6, 7)) * units.kelvin
+    data_rh = np.linspace(0, 1, 5 * 6 * 7).reshape((5, 6, 7)) * units.dimensionless
     ds = xr.Dataset(
         {
             'temperature': (['isobaric', 'lat', 'lon'], data_temp),
@@ -42,15 +43,13 @@ def test_ds_lonlat():
             )
         }
     )
-    ds['temperature'].attrs['units'] = 'kelvin'
-    ds['relative_humidity'].attrs['units'] = 'dimensionless'
     return ds.metpy.parse_cf()
 
 
 @pytest.fixture()
 def test_ds_xy():
     """Return dataset on a x/y grid with a time coordinate for use in tests."""
-    data_temperature = np.linspace(250, 300, 5 * 6 * 7).reshape((1, 5, 6, 7))
+    data_temperature = np.linspace(250, 300, 5 * 6 * 7).reshape((1, 5, 6, 7)) * units.kelvin
     ds = xr.Dataset(
         {
             'temperature': (['time', 'isobaric', 'y', 'x'], data_temperature),
@@ -58,7 +57,7 @@ def test_ds_xy():
         },
         coords={
             'time': xr.DataArray(
-                np.array([np.datetime64('2018-07-01T00:00')]),
+                np.array(['2018-07-01T00:00'], dtype='datetime64[ns]'),
                 name='time',
                 dims=['time']
             ),
@@ -83,7 +82,6 @@ def test_ds_xy():
         }
     )
     ds['temperature'].attrs = {
-        'units': 'kelvin',
         'grid_mapping': 'lambert_conformal'
     }
     ds['lambert_conformal'].attrs = {
@@ -109,9 +107,10 @@ def test_interpolate_to_slice_against_selection(test_ds_lonlat):
     assert_array_almost_equal(true_slice.metpy.unit_array, test_slice.metpy.unit_array, 5)
 
 
+@needs_cartopy
 def test_geodesic(test_ds_xy):
     """Test the geodesic construction."""
-    crs = test_ds_xy['temperature'].metpy.cartopy_crs
+    crs = test_ds_xy['temperature'].metpy.pyproj_crs
     path = geodesic(crs, (36.46, -112.45), (42.95, -68.74), 7)
     truth = np.array([[-4.99495719e+05, -1.49986599e+06],
                       [9.84044354e+04, -1.26871737e+06],
@@ -123,6 +122,7 @@ def test_geodesic(test_ds_xy):
     assert_array_almost_equal(path, truth, 0)
 
 
+@needs_cartopy
 def test_cross_section_dataarray_and_linear_interp(test_ds_xy):
     """Test the cross_section function with a data array and linear interpolation."""
     data = test_ds_xy['temperature']
@@ -150,7 +150,7 @@ def test_cross_section_dataarray_and_linear_interp(test_ds_xy):
         truth_values_x,
         name='x',
         coords={
-            'crs': data['crs'],
+            'metpy_crs': data['metpy_crs'],
             'y': (['index'], truth_values_y),
             'x': (['index'], truth_values_x),
             'index': index,
@@ -161,7 +161,7 @@ def test_cross_section_dataarray_and_linear_interp(test_ds_xy):
         truth_values_y,
         name='y',
         coords={
-            'crs': data['crs'],
+            'metpy_crs': data['metpy_crs'],
             'y': (['index'], truth_values_y),
             'x': (['index'], truth_values_x),
             'index': index,
@@ -169,18 +169,17 @@ def test_cross_section_dataarray_and_linear_interp(test_ds_xy):
         dims=['index']
     )
     data_truth = xr.DataArray(
-        truth_values,
+        truth_values * units.kelvin,
         name='temperature',
         coords={
             'time': data['time'],
             'isobaric': data['isobaric'],
             'index': index,
-            'crs': data['crs'],
+            'metpy_crs': data['metpy_crs'],
             'y': data_truth_y,
             'x': data_truth_x
         },
-        dims=['time', 'isobaric', 'index'],
-        attrs={'units': 'kelvin'}
+        dims=['time', 'isobaric', 'index']
     )
 
     xr.testing.assert_allclose(data_truth, data_cross)
@@ -194,14 +193,15 @@ def test_cross_section_dataarray_projection_noop(test_ds_xy):
     xr.testing.assert_identical(data, data_cross)
 
 
+@needs_cartopy
 def test_cross_section_dataset_and_nearest_interp(test_ds_lonlat):
     """Test the cross_section function with a dataset and nearest interpolation."""
     start, end = (30.5, 255.5), (44.5, 274.5)
     data_cross = cross_section(test_ds_lonlat, start, end, steps=7, interp_type='nearest')
     nearest_values = test_ds_lonlat.isel(lat=xr.DataArray([0, 1, 2, 3, 3, 4, 5], dims='index'),
                                          lon=xr.DataArray(range(7), dims='index'))
-    truth_temp = nearest_values['temperature'].values
-    truth_rh = nearest_values['relative_humidity'].values
+    truth_temp = nearest_values['temperature'].metpy.unit_array
+    truth_rh = nearest_values['relative_humidity'].metpy.unit_array
     truth_values_lon = np.array([255.5, 258.20305939, 261.06299342, 264.10041516,
                                  267.3372208, 270.7961498, 274.5])
     truth_values_lat = np.array([30.5, 33.02800969, 35.49306226, 37.88512911, 40.19271688,
@@ -216,7 +216,7 @@ def test_cross_section_dataset_and_nearest_interp(test_ds_lonlat):
         coords={
             'isobaric': test_ds_lonlat['isobaric'],
             'index': index,
-            'crs': test_ds_lonlat['crs'],
+            'metpy_crs': test_ds_lonlat['metpy_crs'],
             'lat': (['index'], truth_values_lat),
             'lon': (['index'], truth_values_lon)
         },
@@ -242,7 +242,7 @@ def test_cross_section_error_on_missing_coordinate(test_ds_lonlat):
     """Test that the proper error is raised with missing coordinate."""
     # Use a variable with no crs coordinate
     data_bad = test_ds_lonlat['temperature'].copy()
-    del data_bad['crs']
+    del data_bad['metpy_crs']
     start, end = (30.5, 255.5), (44.5, 274.5)
 
     with pytest.raises(ValueError):
